/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

[scriptable, uuid(5743f870-958e-4f02-aef2-c0afeef67f05)]
interface nsIPKCS11 : nsISupports
{
  void deleteModule(in AString moduleName);
  void addModule(in AString moduleName,
                 in AString libraryFullPath,
                 in long cryptoMechanismFlags,
                 in long cipherFlags);
};
