/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

AV_FUNC(LIBAVCODEC, avcodec_align_dimensions2)
AV_FUNC(LIBAVCODEC, avcodec_alloc_frame)
AV_FUNC(LIBAVCODEC, avcodec_close)
AV_FUNC(LIBAVCODEC, avcodec_decode_audio4)
AV_FUNC(LIBAVCODEC, avcodec_decode_video2)
AV_FUNC(LIBAVCODEC, avcodec_default_get_buffer)
AV_FUNC(LIBAVCODEC, avcodec_default_release_buffer)
AV_FUNC(LIBAVCODEC, avcodec_find_decoder)
AV_FUNC(LIBAVCODEC, avcodec_flush_buffers)
AV_FUNC(LIBAVCODEC, avcodec_get_context_defaults3)
AV_FUNC(LIBAVCODEC, avcodec_get_edge_width)
AV_FUNC(LIBAVCODEC, avcodec_get_frame_defaults)
AV_FUNC(LIBAVCODEC, avcodec_open2)
AV_FUNC(LIBAVCODEC, av_init_packet)
AV_FUNC(LIBAVCODEC, av_dict_get)

AV_FUNC(LIBAVFORMAT, av_register_all)

AV_FUNC(LIBAVUTIL, av_image_fill_linesizes)
AV_FUNC(LIBAVUTIL, av_image_fill_pointers)
AV_FUNC(LIBAVUTIL, av_log_set_level)
